@@ -1,3 +1,4 @@
+// -*- C++ -*-
 // infodialog.h
 //
 // (C) 2001 Stefan Kebekus
@@ -6,22 +7,15 @@
 #ifndef INFO_KDVI_H
 #define INFO_KDVI_H
 
-#include <qstring.h>
-#include <qvariant.h>
 #include <kdialogbase.h>
 
-class dvifile;
+#include <qstring.h>
 
-class QVBoxLayout;
-class QHBoxLayout;
-class QGridLayout;
-class QLabel;
-class KPushButton;
-class QTabWidget;
-class QTable;
+class dvifile;
+class fontPool;
 class QTextView;
 class QWidget;
-class fontPool;
+
 
 class infoDialog : public KDialogBase
 {
@@ -42,7 +36,7 @@ public:
 public slots:
     /** This slot is called when Output from the MetaFont programm
         is received via the fontpool/kpsewhich */
-    void       outputReceiver(QString);
+    void       outputReceiver(const QString&);
 
     /** This slot is called whenever anything in the fontpool has
         changed. If the infoDialog is shown, the dialog could then
@@ -53,7 +47,7 @@ public slots:
 	headline. The next time output is received via the
 	outputReceiver, the headline is displayed in bold on top of
 	the text view. */
-    void       clear(QString);
+    void       clear(const QString&);
 
 protected:
  bool     MFOutputReceived;
