@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <stdlib.h>
@@ -1232,7 +1232,7 @@ void KIconEditGrid::editPaste(bool paste)
         {
             if(KMessageBox::warningYesNo(this,
                 i18n("The clipboard image is larger than the current"
-                " image!\nPaste as new image?")) == 0)
+                " image!\nPaste as new image?"),QString::null,i18n("Paste"), i18n("Do Not Paste")) == 0)
             {
                 editPasteAsNew();
             }
@@ -2138,15 +2138,15 @@ static bool kdither_32_to_8( const QImage *src, QImage *dst )
 		}
 	}
 
-	delete line1[0];
-	delete line2[0];
-	delete line1[1];
-	delete line2[1];
-	delete line1[2];
-	delete line2[2];
-	delete pv[0];
-	delete pv[1];
-	delete pv[2];
+	delete [] line1[0];
+	delete [] line2[0];
+	delete [] line1[1];
+	delete [] line2[1];
+	delete [] line1[2];
+	delete [] line2[2];
+	delete [] pv[0];
+	delete [] pv[1];
+	delete [] pv[2];
 
 #undef MAX_R
 #undef MAX_G
@@ -2260,3 +2260,4 @@ void KIconEditGrid::setModified(bool m)
 
 
 #include "kicongrid.moc"
+// vim: set ts=4:
