@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004 by Albert Astals Cid <tsdgeos@terra.es>            *
+ *   Copyright (C) 2004-2006 by Albert Astals Cid <tsdgeos@terra.es>       *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -31,6 +31,7 @@ class TOCItem : public KListViewItem
             if ( e.hasAttribute( "Page" ) )
                 setText( 1, e.attribute( "Page" ) );
 #endif
+            setMultiLinesEnabled(true);
         }
 
         TOCItem( KListViewItem *parent, TOCItem *after, const QDomElement & e )
@@ -40,6 +41,7 @@ class TOCItem : public KListViewItem
             if ( e.hasAttribute( "Page" ) )
                 setText( 1, e.attribute( "Page" ) );
 #endif
+            setMultiLinesEnabled(true);
         }
 
         const QDomElement & element() const
@@ -67,6 +69,11 @@ TOC::TOC(QWidget *parent, KPDFDocument *document) : KListView(parent), m_documen
     connect(this, SIGNAL(returnPressed(QListViewItem *)), this, SLOT(slotExecuted(QListViewItem *)));
 }
 
+TOC::~TOC()
+{
+    m_document->removeObserver( this );
+}
+
 uint TOC::observerId() const
 {
     return TOC_ID;
