@@ -28,7 +28,7 @@
 
 const PMColor colorDefault = PMColor( 1.0, 1.0, 1.0, 0.0, 0.0 );
 
-PMDefinePropertyClass( PMQuickColor, PMProperty );
+PMDefinePropertyClass( PMQuickColor, PMQuickColorProperty );
 
 PMMetaObject* PMQuickColor::s_pMetaObject = 0;
 PMObject* createNewQuickColor( PMPart* part )
@@ -74,7 +74,7 @@ PMMetaObject* PMQuickColor::metaObject( ) const
       s_pMetaObject = new PMMetaObject( "QuickColor", Base::metaObject( ),
                                         createNewQuickColor );
       s_pMetaObject->addProperty(
-         new PMProperty( "color", &PMQuickColor::setColor, &PMQuickColor::color ) );
+         new PMQuickColorProperty( "color", &PMQuickColor::setColor, &PMQuickColor::color ) );
    }
    return s_pMetaObject;
 }
