@@ -33,8 +33,11 @@ const PMVector point2Default = PMVector( 0.0, 0.0, 1.0 );
 const PMVector normal0Default = PMVector( 0.0, 1.0, 0.0 );
 const PMVector normal1Default = PMVector( 0.0, 1.0, 0.0 );
 const PMVector normal2Default = PMVector( 0.0, 1.0, 0.0 );
+const PMVector uvVector0Default = PMVector( 0.0, 0.0 );
+const PMVector uvVector1Default = PMVector( 1.0, 0.0 );
+const PMVector uvVector2Default = PMVector( 0.5, 1.0 );
 
-PMDefinePropertyClass( PMTriangle, PMProperty );
+PMDefinePropertyClass( PMTriangle, PMTriangleProperty );
 
 class PMPointProperty : public PMPropertyBase
 {
@@ -108,6 +111,43 @@ private:
    int m_index;
 };
 
+class PMUVVectorProperty : public PMPropertyBase
+{
+public:
+   PMUVVectorProperty( )
+         : PMPropertyBase( "uvVectors", PMVariant::Vector )
+   {
+      m_index = 0;
+   }
+   virtual int dimensions( ) const { return 1; }
+   virtual void setIndex( int /*dimension*/, int index )
+   {
+      if( index < 0 || index > 2 )
+         kdError( PMArea ) << "Illegal index in PMTriangle::UVVectorProperty::setIndex" << endl;
+      else
+         m_index = index;
+   }
+   virtual int size( PMObject* /*object*/, int /*dimension*/ ) const
+   {
+      return 2;
+   }
+protected:
+   virtual bool setProtected( PMObject* obj, const PMVariant& v )
+   {
+      PMTriangle* p = ( PMTriangle* ) obj;
+      p->setUVVector( m_index, v.vectorData( ) );
+      return true;
+   }
+   virtual PMVariant getProtected( const PMObject* obj )
+   {
+      const PMTriangle* p = ( const PMTriangle* ) obj;
+      return PMVariant( p->uvVector( m_index ) );
+   }
+
+private:
+   int m_index;
+};
+
 PMMetaObject* PMTriangle::s_pMetaObject = 0;
 PMObject* createNewTriangle( PMPart* part )
 {
@@ -125,6 +165,10 @@ PMTriangle::PMTriangle( PMPart* part )
    m_normal[1] = normal1Default;
    m_normal[2] = normal2Default;
    m_smooth = false;
+   m_uvVector[0] = uvVector0Default;
+   m_uvVector[1] = uvVector1Default;
+   m_uvVector[2] = uvVector2Default;
+   m_uvEnabled = false;
 }
 
 PMTriangle::PMTriangle( const PMTriangle& t )
@@ -135,8 +179,10 @@ PMTriangle::PMTriangle( const PMTriangle& t )
    {
       m_point[i] = t.m_point[i];
       m_normal[i] = t.m_normal[i];
+      m_uvVector[i] = t.m_uvVector[i];
    }
    m_smooth = t.m_smooth;
+   m_uvEnabled = t.m_uvEnabled;
 }
 
 PMTriangle::~PMTriangle( )
@@ -159,6 +205,10 @@ void PMTriangle::serialize( QDomElement& e, QDomDocument& doc ) const
    e.setAttribute( "normal1", m_normal[1].serializeXML( ) );
    e.setAttribute( "normal2", m_normal[2].serializeXML( ) );
    e.setAttribute( "smooth", m_smooth );
+   e.setAttribute( "uvVector0", m_uvVector[0].serializeXML( ) );
+   e.setAttribute( "uvVector1", m_uvVector[1].serializeXML( ) );
+   e.setAttribute( "uvVector2", m_uvVector[2].serializeXML( ) );
+   e.setAttribute( "uvEnabled", m_uvEnabled );
    Base::serialize( e, doc );
 }
 
@@ -171,6 +221,10 @@ void PMTriangle::readAttributes( const PMXMLHelper& h )
    m_normal[1] = h.vectorAttribute( "normal1", normal1Default );
    m_normal[2] = h.vectorAttribute( "normal2", normal2Default );
    m_smooth = h.boolAttribute( "smooth", false );
+   m_uvVector[0] = h.vectorAttribute( "uvVector0", uvVector0Default );
+   m_uvVector[1] = h.vectorAttribute( "uvVector1", uvVector1Default );
+   m_uvVector[2] = h.vectorAttribute( "uvVector2", uvVector2Default );
+   m_uvEnabled = h.boolAttribute( "uvEnabled", m_uvEnabled );
    Base::readAttributes( h );
 }
 
@@ -181,10 +235,11 @@ PMMetaObject* PMTriangle::metaObject( ) const
       s_pMetaObject = new PMMetaObject( "Triangle", Base::metaObject( ),
                                         createNewTriangle );
       s_pMetaObject->addProperty(
-         new PMProperty( "smooth", &PMTriangle::setSmoothTriangle,
+         new PMTriangleProperty( "smooth", &PMTriangle::setSmoothTriangle,
                          &PMTriangle::isSmoothTriangle ) );
       s_pMetaObject->addProperty( new PMPointProperty( ) );
       s_pMetaObject->addProperty( new PMNormalProperty( ) );
+      s_pMetaObject->addProperty( new PMUVVectorProperty( ) );
    }
    return s_pMetaObject;
 }
@@ -211,7 +266,7 @@ PMVector PMTriangle::point( int i ) const
    if( ( i >= 0 ) && ( i <= 2 ) )
       return m_point[i];
    else
-      kdError( PMArea ) << "Wrong index in PMTriangle::setPoint\n";
+      kdError( PMArea ) << "Wrong index in PMTriangle::point\n";
    return PMVector( 0.0, 0.0, 0.0 );
 }
 
@@ -237,7 +292,7 @@ PMVector PMTriangle::normal( int i ) const
    if( ( i >= 0 ) && ( i <= 2 ) )
       return m_normal[i];
    else
-      kdError( PMArea ) << "Wrong index in PMTriangle::setNormal\n";
+      kdError( PMArea ) << "Wrong index in PMTriangle::normal\n";
    return PMVector( 0.0, 0.0, 0.0 );
 }
 
@@ -255,6 +310,41 @@ void PMTriangle::setSmoothTriangle( bool on )
    }
 }
 
+PMVector PMTriangle::uvVector( int i ) const
+{
+   if( i >= 0 && i < 3 )
+      return m_uvVector[i];
+   else
+      kdError( PMArea ) << "Wrong index in PMTriangle::uvVector\n";
+   return PMVector( 0.0, 0.0 );
+}
+
+void PMTriangle::setUVVector( int i, const PMVector& v )
+{
+   if( i >= 0 && i < 3 )
+   {
+      if( v != m_uvVector[i] )
+      {
+         if( m_pMemento )
+            m_pMemento->addData( s_pMetaObject, PMUVVector0ID + i, m_uvVector[i] );
+         m_uvVector[i] = v;
+         m_uvVector[i].resize( 2 );
+      }
+   }
+   else
+      kdError( PMArea ) << "Wrong index in PMTriangle::setNormal\n";
+}
+
+void PMTriangle::enableUV( bool yes )
+{
+   if( yes != m_uvEnabled )
+   {
+      if( m_pMemento )
+         m_pMemento->addData( s_pMetaObject, PMUVEnabledID, m_uvEnabled );
+      m_uvEnabled = yes;
+   }
+}
+
 PMDialogEditBase* PMTriangle::editWidget( QWidget* parent ) const
 {
    return new PMTriangleEdit( parent );
@@ -293,6 +383,18 @@ void PMTriangle::restoreMemento( PMMemento* s )
             case PMSmoothID:
                setSmoothTriangle( data->boolData( ) );
                break;
+            case PMUVVector0ID:
+               setUVVector( 0, data->vectorData( ) );
+               break;
+            case PMUVVector1ID:
+               setUVVector( 1, data->vectorData( ) );
+               break;
+            case PMUVVector2ID:
+               setUVVector( 2, data->vectorData( ) );
+               break;
+            case PMUVEnabledID:
+               enableUV( data->boolData( ) );
+               break;
             default:
                kdError( PMArea ) << "Wrong ID in PMTriangle::restoreMemento\n";
                break;
