@@ -14,8 +14,8 @@
 
     You should have received a copy of the GNU Library General Public License
     along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-    Boston, MA 02111-1307, USA.
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include <kdebug.h>
@@ -756,6 +756,7 @@ bool SVGSVGElementImpl::prepareMouseEvent(const QPoint &p, const QPoint &a, SVGM
 // Ecma stuff
 
 /*
+@namespace KSVG
 @begin SVGSVGElementImpl::s_hashTable 23
  x							SVGSVGElementImpl::X						DontDelete|ReadOnly
  y							SVGSVGElementImpl::Y						DontDelete|ReadOnly
@@ -777,6 +778,7 @@ bool SVGSVGElementImpl::prepareMouseEvent(const QPoint &p, const QPoint &a, SVGM
  onzoom						SVGSVGElementImpl::OnZoom					DontDelete
  onscroll					SVGSVGElementImpl::OnScroll					DontDelete
 @end
+@namespace KSVG
 @begin SVGSVGElementImplProto::s_hashTable 29
  createSVGNumber					SVGSVGElementImpl::CreateSVGNumber				DontDelete|Function 0
  createSVGLength					SVGSVGElementImpl::CreateSVGLength				DontDelete|Function 0
