@@ -59,7 +59,7 @@ K_EXPORT_COMPONENT_FACTORY(kviewerpart, KViewPartFactory)
 KViewPart::KViewPart(QWidget *parentWidget, const char *widgetName, QObject *parent,
                      const char *name, const QStringList& args)
   : KViewPart_Iface(parent, name), showSidebar(0), saveAction(0), partManager(0),
-    multiPage(0), multiPageLibrary(QString::null), aboutDialog(0)
+    multiPageLibrary(QString::null), aboutDialog(0)
 {
   KGlobal::locale()->insertCatalogue("kviewshell");
 
@@ -146,7 +146,7 @@ KViewPart::KViewPart(QWidget *parentWidget, const char *widgetName, QObject *par
       reason = i18n("<qt>The factory does not support creating components of the specified type.</qt>");
       break;
     }
-    
+
     QString text = i18n("<qt><p><b>Problem:</b> The document <b>%1</b> cannot be shown.</p>"
 			"<p><b>Reason:</b> The software component <b>%2</b> which is required to "
 			"display your files could not be initialized. This could point to "
@@ -233,7 +233,7 @@ KViewPart::KViewPart(QWidget *parentWidget, const char *widgetName, QObject *par
   media->setItems(items);
   connect (media, SIGNAL(activated(int)), this, SLOT(slotMedia(int)));
 
-  useDocumentSpecifiedSize = new KToggleAction(i18n("&Use Document Specified Paper Size"), 0, this, SLOT(slotShowSidebar()), 
+  useDocumentSpecifiedSize = new KToggleAction(i18n("&Use Document Specified Paper Size"), 0, this, SLOT(slotShowSidebar()),
 					       actionCollection(), "view_use_document_specified_size");
 
   // Zoom Actions
@@ -283,9 +283,9 @@ KViewPart::KViewPart(QWidget *parentWidget, const char *widgetName, QObject *par
   //connect(selectionModeAction, SIGNAL(toggled(bool)), this, SLOT(slotEnableSelectionTool(bool)));
 
   // history action
-  backAction = new KAction(i18n("&Back"), "1leftarrow", 0, 
+  backAction = new KAction(i18n("&Back"), "1leftarrow", 0,
                    this, SLOT(mp_doGoBack()), actionCollection(), "go_back");
-  forwardAction = new KAction(i18n("&Forward"), "1rightarrow", 0, 
+  forwardAction = new KAction(i18n("&Forward"), "1rightarrow", 0,
                       this, SLOT(mp_doGoForward()), actionCollection(), "go_forward");
 
   backAction->setEnabled(false);
@@ -338,6 +338,8 @@ KViewPart::KViewPart(QWidget *parentWidget, const char *widgetName, QObject *par
 
 KViewPart::~KViewPart()
 {
+  writeSettings();
+
   // Without the next two lines, konqueror crashes when it is quit
   // while displaying a DVI file. I don't really understand
   // why... --Stefan.
@@ -348,7 +350,6 @@ KViewPart::~KViewPart()
   setManager(0);
   delete partManager;
 
-  writeSettings();
   delete multiPage;
   delete tmpUnzipped;
 }
@@ -420,7 +421,7 @@ QString KViewPart::pageSizeDescription()
   if (s.formatNumber() == -1) {
     if (KGlobal::locale()-> measureSystem() == KLocale::Metric)
       size += QString("%1x%2 mm").arg(s.width().getLength_in_mm(), 0, 'f', 0).arg(s.height().getLength_in_mm(), 0, 'f', 0);
-    else 
+    else
       size += QString("%1x%2 in").arg(s.width().getLength_in_inch(), 0, 'g', 2).arg(s.height().getLength_in_inch(), 0, 'g', 2);
   } else {
     size += s.formatName() + "/";
@@ -451,8 +452,8 @@ void KViewPart::saveDocumentRestoreInfo(KConfig* config)
 void KViewPart::slotFileOpen()
 {
   if ((!multiPage.isNull()) && (multiPage->isModified() == true)) {
-    int ans = KMessageBox::warningContinueCancel( 0, 
-					 i18n("Your document has been modified. Do you really want to open another document?"), 
+    int ans = KMessageBox::warningContinueCancel( 0,
+					 i18n("Your document has been modified. Do you really want to open another document?"),
 					 i18n("Warning - Document Was Modified"),KStdGuiItem::open());
     if (ans == KMessageBox::Cancel)
       return;
@@ -634,7 +635,7 @@ bool KViewPart::openFile()
       if (fi.exists())
       {
         m_file = m_file+"."+(*it);
-        break; 
+        break;
       }
     }
 
@@ -665,7 +666,7 @@ bool KViewPart::openFile()
       delete tmpUnzipped;
 
     tmpUnzipped = new KTempFile;
-    if (tmpUnzipped == 0L) 
+    if (tmpUnzipped == 0L)
     {
       KMessageBox::error(mainWidget, i18n("<qt><strong>File Error!</strong> Could not create "
                          "temporary file.</qt>"));
@@ -801,7 +802,7 @@ bool KViewPart::openFile()
     int error;
     multiPage = static_cast<KMultiPage*>(KParts::ComponentFactory::createInstanceFromService<KParts::ReadOnlyPart>(service, mainWidget,
 														   service->name().utf8(), QStringList(), &error ));
-    
+
     if (multiPage.isNull()) {
       QString reason;
       switch(error) {
@@ -844,9 +845,6 @@ bool KViewPart::openFile()
     // Remember the name of the part. So only need to switch if really necessary.
     multiPageLibrary = service->library();
 
-    insertChild(multiPage);
-    removeChild(oldMultiPage);
-
     connect(partManager, SIGNAL(activePartChanged(KParts::Part*)), this, SIGNAL(pluginChanged(KParts::Part*)));
 
     // Switch to the new multiPage
@@ -860,10 +858,7 @@ bool KViewPart::openFile()
     // TODO: Get rid of this without causing nasty artifacts.
     kapp->processEvents();
     initializeMultiPage();
-
-    // This is a bit strange. We need to set the focus to the mainWidget because only then
-    // the KViewPart recieves a KParts::GUIActivateEvent which triggers the GUI merge.
-    mainWidget->setFocus();
+    partManager->setActivePart(this);
 
     // We disconnect because we dont want some FocusEvents to trigger a GUI update, which might mess
     // with our menus.
@@ -930,13 +925,13 @@ bool KViewPart::closeURL_ask()
     return false;
 
   if (multiPage->isModified() == true) {
-    int ans = KMessageBox::warningContinueCancel( 0, 
-					 i18n("Your document has been modified. Do you really want to close it?"), 
+    int ans = KMessageBox::warningContinueCancel( 0,
+					 i18n("Your document has been modified. Do you really want to close it?"),
 					 i18n("Document Was Modified"), KStdGuiItem::close());
     if (ans == KMessageBox::Cancel)
       return false;
   }
-  
+
   return closeURL();
 }
 
@@ -945,16 +940,16 @@ bool KViewPart::closeURL()
 {
   if (multiPage.isNull())
     return false;
-  
+
   if( watch && !m_file.isEmpty() )
     watch->removeFile( m_file );
-  
+
   KParts::ReadOnlyPart::closeURL();
   multiPage->closeURL();
   m_url = QString::null;
   checkActions();
   emit setWindowCaption("");
-  
+
   return true;
 }
 
@@ -968,7 +963,7 @@ void KViewPart::slotMedia(int id)
     userRequestedPaperSize.setPageSize(media->currentText());
     return;
   }
-  
+
   // If the user has chosen "Custom paper size..", show the paper size
   // dialog. Construct it, if necessary. The paper size dialog will
   // know the address of userRequestedPaperSize and change this
@@ -1013,7 +1008,7 @@ void KViewPart::pageInfo(int numpages, int currentpage)
 void KViewPart::goToPage()
 {
   bool ok = false;
-  int p = KInputDialog::getInteger(i18n("Go to Page"), i18n("Page:"), 
+  int p = KInputDialog::getInteger(i18n("Go to Page"), i18n("Page:"),
                                    multiPage->currentPageNumber(), 1, multiPage->numberOfPages(),
                                    1 /*step*/, &ok, mainWidget, "gotoDialog");
   if (ok)
@@ -1029,7 +1024,7 @@ void KViewPart::disableZoomFit()
     enableFitToPage(false);
   }
   else if(fitWidthAct -> isChecked())
-  {  
+  {
     fitWidthAct -> setChecked(false);
     enableFitToWidth(false);
   }
@@ -1137,7 +1132,7 @@ void KViewPart::enableFitToHeight(bool enable)
 
 void KViewPart::fitToPage()
 {
-  double z = QMIN(multiPage->calculateFitToHeightZoomValue(), 
+  double z = QMIN(multiPage->calculateFitToHeightZoomValue(),
                   multiPage->calculateFitToWidthZoomValue());
 
   // Check if the methods returned usable values. Values that are not
@@ -1362,12 +1357,6 @@ void KViewPart::readSettings()
 
 void KViewPart::writeSettings()
 {
-  // if loading the KPart failed - just exit now
-  //if (!showSidebar)
-  //  return;
-
-  multiPage->writeSettings();
-
   KVSPrefs::setPageMarks(showSidebar->isChecked());
   KVSPrefs::setWatchFile(watchAct->isChecked());
   KVSPrefs::setZoom(_zoomVal.value());
@@ -1375,6 +1364,9 @@ void KViewPart::writeSettings()
   KVSPrefs::setScrollbars(scrollbarHandling->isChecked());
   KVSPrefs::setUseDocumentSpecifiedSize(useDocumentSpecifiedSize->isChecked());
 
+  if (!multiPage.isNull())
+    multiPage->writeSettings();
+
   if (fitPageAct->isChecked())
     KVSPrefs::setFitToPage(KVSPrefs::EnumFitToPage::FitToPage);
   else if(fitWidthAct->isChecked())
